from __future__ import print_function


def validate_project_slug():
    project_slug = "{{ cookiecutter.__project_slug }}"
    if hasattr(project_slug, "isidentifier"):
        assert (project_slug.isidentifier()), "'{}' project slug is not a valid Python identifier.".format(project_slug)

    assert (project_slug == project_slug.lower()), "'{}' project slug should be all lowercase".format(project_slug)


def validate_author():
    assert ("\\" not in "{{ cookiecutter.author }}"), "Don't include backslashes in author."


if __name__ == "__main__":
    validate_project_slug()
    validate_author()



import os
import shutil


def generate_license():
    if "{{cookiecutter.license}}" != "None":
        os.rename(os.path.join("LICENSES", "{{cookiecutter.license}}"), "LICENSE")
    shutil.rmtree("LICENSES")


def remove_dotgitlabciyml_file():
    os.remove(".gitlab-ci.yml")


def remove_github_actions():
    shutil.rmtree(".github")


def remove_bitbucket_pipeline_yml_file():
    os.remove("bitbucket-pipelines.yml")

def display_message_to_user():
    cicd_message = "setup the CI/CD pipeline and " if "{{cookiecutter.ci_tool}}" != "None" else ""
    message = f"\033[1mPlease read the comments from README.rst in your project to get to know how to {cicd_message}use commands from Makefile.\033[0m"
    print(message)

if __name__ == "__main__":
    generate_license()
    if "{{cookiecutter.ci_tool}}" != "GitLab":
        remove_dotgitlabciyml_file()
    if "{{cookiecutter.ci_tool}}" != "GitHub":
        remove_github_actions()
    if "{{cookiecutter.ci_tool}}" != "Bitbucket":
        remove_bitbucket_pipeline_yml_file()
    display_message_to_user()
